% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gg_sf.R
\name{gg_sf}
\alias{gg_sf}
\title{Sf ggplot}
\usage{
gg_sf(
  data = NULL,
  col = NULL,
  facet = NULL,
  facet2 = NULL,
  group = NULL,
  position = "identity",
  coord = ggplot2::coord_sf(),
  pal = NULL,
  pal_na = "#88837D",
  ...,
  title = NULL,
  subtitle = NULL,
  x_grid = FALSE,
  x_title = NULL,
  y_grid = FALSE,
  y_title = NULL,
  col_breaks = NULL,
  col_continuous = "gradient",
  col_include = NULL,
  col_labels = NULL,
  col_legend_place = NULL,
  col_legend_ncol = NULL,
  col_legend_nrow = NULL,
  col_legend_rev = FALSE,
  col_limits = NULL,
  col_oob = scales::oob_keep,
  col_rescale = NULL,
  col_title = NULL,
  col_trans = "identity",
  facet_labels = NULL,
  facet_ncol = NULL,
  facet_nrow = NULL,
  facet_scales = "fixed",
  facet_space = "fixed",
  facet_layout = NULL,
  caption = NULL,
  titles = snakecase::to_sentence_case,
  theme = gg_theme(),
  void = TRUE
)
}
\arguments{
\item{data}{A data frame or tibble.}

\item{col}{Unquoted col and fill aesthetic variable.}

\item{facet}{Unquoted facet aesthetic variable.}

\item{facet2}{Unquoted second facet variable.}

\item{group}{Unquoted group aesthetic variable.}

\item{position}{Position adjustment. Either a character string (e.g."identity"), or a function (e.g. ggplot2::position_identity()).}

\item{coord}{A coordinate function from ggplot2 (e.g. ggplot2::coord_cartesian()).}

\item{pal}{Colours to use. A character vector of hex codes (or names).}

\item{pal_na}{Colour to use for NA values. A character vector of a hex code (or name).}

\item{...}{Other arguments passed to the ggplot2::geom_sf function.}

\item{title}{Title string.}

\item{subtitle}{Subtitle string.}

\item{x_grid}{TRUE or FALSE for vertical x gridlines. NULL guesses based on the classes of the x and y.}

\item{x_title}{Axis title string. Defaults to converting to sentence case with spaces. Use "" for no title.}

\item{y_grid}{TRUE or FALSE of horizontal y gridlines. NULL guesses based on the classes of the x and y.}

\item{y_title}{Axis title string. Defaults to converting to sentence case with spaces. Use "" for no title.}

\item{col_breaks}{A function on the limits (e.g. scales::breaks_pretty()), or a vector of breaks.}

\item{col_continuous}{Type of colouring for a continuous variable. Either "gradient" or "steps". Defaults to "steps" - or just the first letter of these e.g. "g".}

\item{col_include}{For a numeric or date variable, any values that the scale should include (e.g. 0).}

\item{col_labels}{A function that takes the breaks as inputs (e.g. scales::label_comma()), or a vector of labels. Note this does not affect where col_intervals is not NULL.}

\item{col_legend_place}{The place for the legend. Either "bottom", "right", "top" or "left" - or just the first letter of these e.g. "b".}

\item{col_legend_ncol}{The number of columns for the legend elements.}

\item{col_legend_nrow}{The number of rows for the legend elements.}

\item{col_legend_rev}{Reverse the elements of the legend. Defaults to FALSE.}

\item{col_limits}{A vector to determine the limits of the colour scale.}

\item{col_oob}{A scales::oob_* function that handles values outside of limits for continuous scales. Defaults to scales::oob_keep.}

\item{col_rescale}{For a continuous col variable, a vector to rescale the pal non-linearly.}

\item{col_title}{Legend title string. Defaults to converting to sentence case with spaces. Use "" for no title.}

\item{col_trans}{For a numeric variable, a transformation object (e.g. "log10", "sqrt" or "reverse").}

\item{facet_labels}{A function that takes the breaks as inputs (e.g. scales::label_comma()), or a named vector of labels (e.g. c("value" = "label", ...)).}

\item{facet_ncol}{The number of columns of facets. Only applies to a facet layout of "wrap".}

\item{facet_nrow}{The number of rows of facets. Only applies to a facet layout of "wrap".}

\item{facet_scales}{Whether facet scales should be "fixed" across facets, "free" in both directions, or free in just one direction (i.e. "free_x" or "free_y"). Defaults to "fixed".}

\item{facet_space}{Whether facet space should be "fixed" across facets, "free" to be proportional in both directions, or free to be proportional in just one direction (i.e. "free_x" or "free_y"). Defaults to "fixed". Only applies where the facet layout is "grid" and facet scales are not "fixed".}

\item{facet_layout}{Whether the layout is to be "wrap" or "grid". If NULL and a single facet (or facet2) argument is provided, then defaults to "wrap". If NULL and both facet and facet2 arguments are provided, defaults to "grid".}

\item{caption}{Caption title string.}

\item{titles}{A function to format the x, y and col titles. Defaults to snakecase::to_sentence_case.}

\item{theme}{A ggplot2 theme.}

\item{void}{TRUE or FALSE of whether to remove axis lines, ticks and x and y titles and labels.}
}
\value{
A ggplot object.
}
\description{
Create a blank ggplot with a wrapper around the ggplot2::geom_sf function.
}
\examples{
if (requireNamespace("sf", quietly = TRUE)) {
  nc <- sf::st_read(system.file("shape/nc.shp", package = "sf"), quiet = TRUE)

  nc |>
    gg_sf(
      col = AREA,
      pal = viridis::cividis(9))
}

}
